import { useContext } from "react";
import { AppContext, AppStyles } from "../../utils";
import Icon from "@expo/vector-icons/MaterialCommunityIcons";
import { Modal, Text, TouchableOpacity, View } from "react-native";
import { Divider } from "../Divider";

export default function PickerModal({ isOpen, setIsOpen, items }) {
  const appContext = useContext(AppContext);
  const closeModal = () => setIsOpen(false);

  return (
    <Modal
      visible={isOpen}
      animationType="slide"
      onRequestClose={() => closeModal()}
    >
      <View
        style={{
          flex: 1,
          backgroundColor: appContext.appTheme.backgroundColor,
        }}
      >
        <TouchableOpacity
          onPress={() => {
            console.log("press");
            setIsOpen(false);
          }}
        >
          <Icon
            name="window-close"
            size={24}
            style={{ marginLeft: 10, marginTop: 20, marginBottom: 20 }}
            color={appContext.appTheme.icon}
          />
        </TouchableOpacity>

        {items.map((item, i) => {
          return item.selected ? (
            <View key={i}>
              <TouchableOpacity onPress={() => closeModal()}>
                <View
                  style={{
                    flexDirection: "row",
                    justifyContent: "space-between",
                    marginLeft: 20,
                    marginRight: 20,
                  }}
                >
                  <Text
                    style={[
                      AppStyles.typography16,
                      { color: appContext.appTheme.text },
                    ]}
                  >
                    {item.label}
                  </Text>
                  <Icon
                    name="check"
                    size={24}
                    color={appContext.appTheme.colors.primary}
                  />
                </View>
              </TouchableOpacity>
              <Divider />
            </View>
          ) : (
            <View key={i}>
              <TouchableOpacity
                onPress={() => {
                  closeModal();
                  item.onPress();
                }}
              >
                <Text
                  style={[
                    AppStyles.typography16,
                    { marginLeft: 20, color: appContext.appTheme.text },
                  ]}
                >
                  {item.label}
                </Text>
              </TouchableOpacity>
              <Divider />
            </View>
          );
        })}
      </View>
    </Modal>
  );
}
